```{include} ../README.md

```

```{toctree}
:caption: 'API'
:hidden: true
:maxdepth: 1

api/model
api/tools
api/plotting
api/metrics
```

```{toctree}
:caption: 'General'
:hidden: true
:maxdepth: 1

changelog.md
contributing.md
references.md
```

```{toctree}
:caption: 'Usage'
:hidden: true
:maxdepth: 1

tutorials/index.md
```
